@@ -24,6 +24,7 @@
 #include <time.h>
 
 #include <ladspa.h>
+#include "tap_platform.h"
 #include "tap_utils.h"
 
 
@@ -434,10 +435,10 @@ LADSPA_Descriptor * stereo_descriptor = NULL;
 
 
 
-/* __attribute__((constructor)) tap_init() is called automatically when the plugin library is first
+/* tap_init() is called automatically when the plugin library is first
    loaded. */
-void 
-__attribute__((constructor)) tap_init() {
+void
+__CONSTRUCTOR tap_init() {
 	
 	char ** port_names;
 	LADSPA_PortDescriptor * port_descriptors;
@@ -573,9 +574,9 @@ delete_descriptor(LADSPA_Descriptor * descriptor) {
 }
 
 
-/* __attribute__((destructor)) tap_fini() is called automatically when the library is unloaded. */
+/* tap_fini() is called automatically when the library is unloaded. */
 void
-__attribute__((destructor)) tap_fini() {
+__DESTRUCTOR tap_fini() {
 	delete_descriptor(stereo_descriptor);
 }
 
@@ -591,3 +592,5 @@ ladspa_descriptor(unsigned long Index) {
 		return NULL;
 	}
 }
+
+__INIT_FINI(tap_init, tap_fini);
