@@ -16,16 +16,15 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
 #include <ladspa.h>
+#include "tap_platform.h"
 #include "tap_utils.h"
 
-
 /* The Unique ID of the plugin: */
 
 #define ID_MONO         2157
@@ -226,10 +225,10 @@ cleanup_Sigmoid(LADSPA_Handle Instance) {
 LADSPA_Descriptor * mono_descriptor = NULL;
 
 
-/* __attribute__((constructor)) tap_init() is called automatically when the plugin library is first
+/* tap_init() is called automatically when the plugin library is first
    loaded. */
 void 
-__attribute__((constructor)) tap_init() {
+__CONSTRUCTOR tap_init() {
 	
 	char ** port_names;
 	LADSPA_PortDescriptor * port_descriptors;
@@ -315,14 +314,12 @@ delete_descriptor(LADSPA_Descriptor * descriptor) {
 	}
 }
 
-
-/* __attribute__((destructor)) tap_fini() is called automatically when the library is unloaded. */
+/* tap_fini() is called automatically when the library is unloaded. */
 void
-__attribute__((destructor)) tap_fini() {
+__DESTRUCTOR tap_fini() {
 	delete_descriptor(mono_descriptor);
 }
 
-
 /* Return a descriptor of the requested plugin type. */
 const LADSPA_Descriptor * 
 ladspa_descriptor(unsigned long Index) {
@@ -334,3 +331,5 @@ ladspa_descriptor(unsigned long Index) {
 		return NULL;
 	}
 }
+
+__INIT_FINI(tap_init, tap_fini);
