@@ -16,13 +16,13 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
 #include <ladspa.h>
+#include "tap_platform.h"
 #include "tap_utils.h"
 
 
@@ -306,10 +306,10 @@ LADSPA_Descriptor * mono_descriptor = NULL;
 
 
 
-/* __attribute__((constructor)) tap_init() is called automatically when the plugin library is first
+/* tap_init() is called automatically when the plugin library is first
    loaded. */
-void 
-__attribute__((constructor)) tap_init() {
+void
+__CONSTRUCTOR tap_init() {
 	
 	int i;
 	char ** port_names;
@@ -423,9 +423,9 @@ delete_descriptor(LADSPA_Descriptor * descriptor) {
 }
 
 
-/* __attribute__((destructor)) tap_fini() is called automatically when the library is unloaded. */
+/* tap_fini() is called automatically when the library is unloaded. */
 void
-__attribute__((destructor)) tap_fini() {
+__DESTRUCTOR tap_fini() {
 	delete_descriptor(mono_descriptor);
 }
 
@@ -441,3 +441,5 @@ ladspa_descriptor(unsigned long Index) {
 		return NULL;
 	}
 }
+
+__INIT_FINI(tap_init, tap_fini);
